@@ -1,7 +1,7 @@
 package Bencher;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2016-01-06'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
@@ -940,6 +940,9 @@ sub format_result {
 $SPEC{bencher} = {
     v => 1.1,
     summary => 'A benchmark framework',
+    args_rels => {
+        # XXX precision is only relevant when action=bench
+    },
     args => {
         scenario_file => {
             summary => 'Load a scenario from a Perl file',
@@ -988,6 +991,10 @@ _
                 d => $_alias_spec_add_dataset,
             },
         },
+        precision => {
+            summary => 'Precision, will be passed to Benchmark::Dumb',
+            schema => ['float*', between=>[0,1]],
+        },
         action => {
             schema => ['str*', {
                 in=>[qw/
@@ -1440,7 +1447,7 @@ sub bencher {
             0 : 1;
 
         $envres->[3]{'func.module_startup'} = $module_startup;
-        $envres->[3]{'func.module_versions'}{perl} = $^V if $return_resmeta;
+        $envres->[3]{'func.module_versions'}{perl} = "$^V" if $return_resmeta;
 
         my $code_load = sub {
             no strict 'refs';
@@ -1548,8 +1555,10 @@ sub bencher {
             $envres->[3]{'func.time_start'} = Time::HiRes::time();
         }
 
+        my $precision = $args{precision} // $parsed->{default_precision} // 0;
+        $log->tracef("Running benchmark (precision=%g) ...", $precision);
         my $tres = Benchmark::Dumb::_timethese_guts(
-            0,
+            $precision,
             {
                 map { $_->{seq} => $_->{code} } @$items
             },
@@ -1656,7 +1665,7 @@ Bencher - A benchmark framework
 
 =head1 VERSION
 
-This document describes version 0.22 of Bencher (from Perl distribution Bencher), released on 2016-01-05.
+This document describes version 0.23 of Bencher (from Perl distribution Bencher), released on 2016-01-06.
 
 =head1 SYNOPSIS
 
@@ -1829,6 +1838,10 @@ will "skip" the item.
 
 Add participants.
 
+=item * B<precision> => I<float>
+
+Precision, will be passed to Benchmark::Dumb.
+
 =item * B<raw> => I<bool>
 
 Show "raw" data.
@@ -2075,6 +2088,13 @@ From DefHash, a one-line plaintext summary.
 
 From DefHash, longer description in Markdown.
 
+=item * module_startup (bool)
+
+=item * default_precision (float, between=>[0,1])
+
+Precision to pass to Benchmark::Dumb. Default is 0. Can be overriden via
+C<--precision> (CLI).
+
 =item * on_failure (str, "skip"|"die")
 
 The default is "die". When set to "skip", will first run the code of each item
